<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://www.vsourz.com
 * @since      1.0.0
 *
 * @package    Acf7db_schedule_report
 * @subpackage Acf7db_schedule_report/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Acf7db_schedule_report
 * @subpackage Acf7db_schedule_report/includes
 * @author     vsourz Digital <support@vsourz.com>
 */
class Acf7db_schedule_report {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Acf7db_schedule_report_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		if ( defined( 'ACF7DB_SCHEDULE_REPORT_VERSION' ) ) {
			$this->version = ACF7DB_SCHEDULE_REPORT_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'acf7db_schedule_report';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Acf7db_schedule_report_Loader. Orchestrates the hooks of the plugin.
	 * - Acf7db_schedule_report_i18n. Defines internationalization functionality.
	 * - Acf7db_schedule_report_Admin. Defines all hooks for the admin area.
	 * - Acf7db_schedule_report_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-acf7db_schedule_report-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-acf7db_schedule_report-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-acf7db_schedule_report-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-acf7db_schedule_report-public.php';

		/**
		 * The class responsible for trigger all schedule related mail templates
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-scheduled_report_emailclass.php';


		$this->loader = new Acf7db_schedule_report_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Acf7db_schedule_report_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Acf7db_schedule_report_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Acf7db_schedule_report_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		//////////////////////////// register custom post type here  //////////////////////////
		$this->loader->add_action( 'init', $plugin_admin, 'vsz_register_acf7db_schedule_report_cpt');
		$this->loader->add_action( 'admin_menu',$plugin_admin, 'vsz_register_acf7db_schedule_report_cpt_sub_menu' ,11);
		// add meta box on custom post type screen
		$this->loader->add_action( 'add_meta_boxes_schedule_report', $plugin_admin, 'vsz_acf7db_schedule_report_register_metaboxes');

		//Change post title place holder
		$this->loader->add_filter('enter_title_here',$plugin_admin,'vsz_acf7db_schedule_report_change_title');

		//Add plugin related custom class in admin screen body tag
		$this->loader->add_filter( 'admin_body_class', $plugin_admin,'vsz_acf7db_schedule_report_add_classes' );

		//Save all custom fields value here
		$this->loader->add_action( 'save_post_schedule_report', $plugin_admin, 'vsz_acf7db_schedule_save_details', 10, 3 );

		// Display error messsage
		$this->loader->add_action( 'admin_notices', $plugin_admin,'vsz_acf7db_schedule_error_notice',0 );
		$this->loader->add_filter( 'post_updated_messages', $plugin_admin,'vsz_acf7db_post_published', 1 );

		// Display run now button
		// $this->loader->add_action( 'post_submitbox_misc_actions', $plugin_admin,'vsz_acfdb_run_now_btn', 1 );
		$this->loader->add_action( 'post_submitbox_start', $plugin_admin,'vsz_acfdb_run_now_btn', 1 );

		/////////////////////////// Edit columns for listing page  ////////////////////////
		$this->loader->add_filter( 'manage_edit-schedule_report_columns', $plugin_admin,'vsz_acf7db_schedule_columns' ) ;
		$this->loader->add_action( 'manage_schedule_report_posts_custom_column', $plugin_admin,'vsz_acf7db_schedule_custom_columns', 10, 2 );

		////////////////////////// Cron schedule filter
		$this->loader->add_filter( 'cron_schedules',$plugin_admin, 'vsz_schedules');
		////////////////////////// Cron register hooks
		$this->loader->add_action('vsz_cron_schedules_hooks', $plugin_admin,'vsz_cron_schedules_hooks_callback');

		// For deleting old files of quick view
		$this->loader->add_action('vsz_quickview_delete_callback', $plugin_admin,'vsz_quickview_delete_callback_func');

		///// Delete cron when delete scadule
		$this->loader->add_action( 'deleted_post',$plugin_admin,'vsz_cron_schedules_delete');

		//Ajax for contact forms fields
		$this->loader->add_action("wp_ajax_vsz_contact_fields",$plugin_admin,"vsz_cron_schedules_contact_fields");
		$this->loader->add_action("wp_ajax_nopriv_vsz_contact_fields",$plugin_admin,"vsz_cron_schedules_contact_fields");

		//Display Advance CF7 DB plugin related error message from here
		$this->loader->add_action( 'admin_notices', $plugin_admin, 'vsz_acf7db_plugin_display_message');

		//Ajax for contact forms fields
		$this->loader->add_action("wp_ajax_acf7db_sr_delete_file_report",$plugin_admin,"acf7db_sr_delete_file_report_callback");
		$this->loader->add_action("wp_ajax_acf7db_sr_run_now",$plugin_admin,"acf7db_sr_run_now_callback");
		$this->loader->add_action("wp_ajax_acf7db_sr_quick_view",$plugin_admin,"acf7db_sr_quick_view_callback");
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Acf7db_schedule_report_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

	}
	/// Cron Schedules Filter Function

	/// Cron Hooks

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}


	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Acf7db_schedule_report_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}


}
//Get website time zone and Set default time zone value for website
function vsz_schedule_report_get_site_time_zone(){
	
	$timezone = get_option('timezone_string');
	if(empty($timezone)){
		$timezone = get_option('gmt_offset');
		$timezoneName = timezone_name_from_abbr("", $timezone*3600, false);
		date_default_timezone_set($timezoneName);
	}
	else{
		date_default_timezone_set($timezone);
	}
}
